# django-searchview
SearchView is a multiple inheritance class of Form and ListView 

When I wanted to make a Search Page with class based View of Django, the first choice was using FormView and ListView.
But, I wanted to display search form and results list in one page.
I needed a new view class, multiple inheritance from FormView and ListView.
I searched for it, but I couldn’t find a good solution. So I made it by myself.

see below.

[DjangoSearchView/searchview](https://github.com/Arisophy/django-searchview/tree/master/DjangoSearchView/searchview)

Code is simple and less than 100 steps. But it's very useful.

## How To Use

https://gijutsu.com/en/2020/12/29/django-searchview-class/

